@@ -226,15 +226,15 @@ class Client(object):
         url_path = '/exports/deleted'
         return self._get_request(url_path)
 
-    def export_create(self, quota, categoria, resource_id=None, time_id=None, audit=False):
+    def export_create(self, quota, categoria, time_id, resource_id=None, audit=False):
         url_path = '/exports'
-        data = {'quota': quota, 'categoria': categoria, 'resource_id': resource_id, 'time_id': time_id}
+        data = {'quota': quota, 'categoria': categoria, 'time_id': time_id, 'resource_id': resource_id}
 
         return self._post_request(url_path, data, audit=audit)
 
-    def export_multiple_create(self, quota, categoria, resource_id=None, time_id=None, amount=None, audit=False):
+    def export_multiple_create(self, quota, categoria, time_id, resource_id=None, amount=None, audit=False):
         url_path = '/exports/multiple'
-        data = {'quota': quota, 'categoria': categoria, 'resource_id': resource_id, 'time_id': time_id, 'amount': amount}
+        data = {'quota': quota, 'categoria': categoria, 'time_id': time_id, 'resource_id': resource_id, 'amount': amount}
 
         return self._post_request(url_path, data, audit=audit)
 
@@ -246,9 +246,9 @@ class Client(object):
         url_path = '/exports/{}/force'.format(export_id_or_path)
         return self._delete_request(url_path, audit=audit)
 
-    def export_update(self, export_id_or_path, quota, audit=False):
+    def export_update(self, export_id_or_path, quota, time_id=None, audit=False):
         url_path = '/exports/{}'.format(export_id_or_path)
-        data = {'quota': quota}
+        data = {'quota': quota, 'time_id': time_id}
 
         return self._put_request(url_path, data, audit=audit)
 
