@@ -158,33 +158,36 @@ class TestFaasclient(unittest.TestCase):
 
         quota = 123456789
         categoria_id = 1
+        time_id = '123456'
 
-        self.client.export_create(quota, categoria_id)
+        self.client.export_create(quota, categoria_id, time_id)
         mock_request.assert_called_once_with('/exports', {
-            'quota': quota, 'categoria': categoria_id, 'resource_id': None, 'time_id': None}, audit=False)
+            'quota': quota, 'categoria': categoria_id, 'resource_id': None, 'time_id': '123456'}, audit=False)
 
     @patch('faasclient.client.Client._post_request')
     def test_export_create_with_resource(self, mock_request):
 
         quota = 123456789
         categoria_id = 1
+        time_id = '123456'
         resource_id = 'aaaa-bbbb-cccc'
 
-        self.client.export_create(quota, categoria_id, resource_id)
+        self.client.export_create(quota, categoria_id, time_id, resource_id)
         mock_request.assert_called_once_with('/exports', {
-            'quota': quota, 'categoria': categoria_id, 'resource_id': 'aaaa-bbbb-cccc', 'time_id': None}, audit=False)
+            'quota': quota, 'categoria': categoria_id, 'time_id': '123456', 'resource_id': 'aaaa-bbbb-cccc'}, audit=False)
 
     @patch('faasclient.client.Client._post_request')
     def test_export_create_multiple_with_amount(self, mock_request):
 
         quota = 123456789
         categoria_id = 1
+        time_id = '123456'
         resource_id = 'aaaa-bbbb-cccc'
         amount = 3
 
-        self.client.export_multiple_create(quota, categoria_id, resource_id, amount=amount)
+        self.client.export_multiple_create(quota, categoria_id, time_id, resource_id=resource_id, amount=amount)
         mock_request.assert_called_once_with('/exports/multiple', {
-            'quota': quota, 'categoria': categoria_id, 'resource_id': 'aaaa-bbbb-cccc', 'time_id': None, 'amount': 3}, audit=False)
+            'quota': quota, 'categoria': categoria_id, 'time_id': '123456', 'resource_id': 'aaaa-bbbb-cccc', 'amount': 3}, audit=False)
 
     @patch('faasclient.client.Client._delete_request')
     def test_export_delete(self, mock_request):
@@ -398,10 +401,12 @@ class TestFaasclient(unittest.TestCase):
 
         id = 123
         quota = 123456789
+        time_id = '123456'
 
-        self.client.export_update(id, quota)
+        self.client.export_update(id, quota, time_id)
         mock_request.assert_called_once_with('/exports/%d' % id, {
-                                             'quota': quota
+                                             'quota': quota,
+                                             'time_id': time_id
                                              }, audit=False)
 
     @patch('faasclient.client.Client._delete_request')
